diff --git a/doc/demuxers.texi b/doc/demuxers.texi
index f0a14e060d94962198ffa23deecee1f6bd3acd59..23cec5a386c74de0b5cc5b25f44435c93f5c183b 100644
--- a/doc/demuxers.texi
+++ b/doc/demuxers.texi
@@ -266,7 +266,7 @@ If set to 1, will set frame timestamp to modification time of image file. Note
 that monotonity of timestamps is not provided: images go in the same order as
 without this option. Default value is 0.
 If set to 2, will set frame timestamp to the modification time of the image file in
-nanosecond precission.
+nanosecond precision.
 @item video_size
 Set the video size of the images to read. If not specified the video
 size is guessed from the first image file in the sequence.
diff --git a/libavcodec/atrac1data.h b/libavcodec/atrac1data.h
index 08f835747a77bec493d6144defd39d846e3b221b..62c218b7906d59c9b0aa131cdc22763c959482b2 100644
--- a/libavcodec/atrac1data.h
+++ b/libavcodec/atrac1data.h
@@ -43,7 +43,7 @@ static const uint8_t bfu_bands_t[4]  = {0, 20, 36, 52};
  */
 static const uint8_t specs_per_bfu[52] = {
      8,  8,  8,  8,  4,  4,  4,  4,  8,  8,  8,  8,  6,  6,  6,  6, 6, 6, 6, 6, // low band
-     6,  6,  6,  6,  7,  7,  7,  7,  9,  9,  9,  9, 10, 10, 10, 10,             // midle band
+     6,  6,  6,  6,  7,  7,  7,  7,  9,  9,  9,  9, 10, 10, 10, 10,             // middle band
     12, 12, 12, 12, 12, 12, 12, 12, 20, 20, 20, 20, 20, 20, 20, 20              // high band
 };
 
diff --git a/libavcodec/avcodec.h b/libavcodec/avcodec.h
index 7eda8bcdc865e773e352fde556836cec78eec554..c41d156e37c712088d19434f089132dfcccb3ef2 100644
--- a/libavcodec/avcodec.h
+++ b/libavcodec/avcodec.h
@@ -2260,7 +2260,7 @@ typedef struct AVCodecContext {
 
     /**
      * ratecontrol qmin qmax limiting method
-     * 0-> clipping, 1-> use a nice continuous function to limit qscale wthin qmin/qmax.
+     * 0-> clipping, 1-> use a nice continuous function to limit qscale within qmin/qmax.
      * - encoding: Set by user.
      * - decoding: unused
      */
@@ -2355,14 +2355,14 @@ typedef struct AVCodecContext {
     int context_model;
 
     /**
-     * minimum Lagrange multipler
+     * minimum Lagrange multiplier
      * - encoding: Set by user.
      * - decoding: unused
      */
     int lmin;
 
     /**
-     * maximum Lagrange multipler
+     * maximum Lagrange multiplier
      * - encoding: Set by user.
      * - decoding: unused
      */
@@ -2587,7 +2587,7 @@ typedef struct AVCodecContext {
 #define AV_EF_EXPLODE   (1<<3)          ///< abort decoding on minor error detection
 
 #define AV_EF_CAREFUL    (1<<16)        ///< consider things that violate the spec, are fast to calculate and have not been seen in the wild as errors
-#define AV_EF_COMPLIANT  (1<<17)        ///< consider all spec non compliancies as errors
+#define AV_EF_COMPLIANT  (1<<17)        ///< consider all spec non compliances as errors
 #define AV_EF_AGGRESSIVE (1<<18)        ///< consider things that a sane encoder should not do as an error
 
 
@@ -2777,7 +2777,7 @@ typedef struct AVCodecContext {
 #endif
 
     /**
-     * noise vs. sse weight for the nsse comparsion function
+     * noise vs. sse weight for the nsse comparison function
      * - encoding: Set by user.
      * - decoding: unused
      */
diff --git a/libavcodec/dirac_dwt.h b/libavcodec/dirac_dwt.h
index 25c13d1a656efa44b321f57e446946b14df19883..e5e447b0ac6dc9f347bbe464d82452dfa89a3ad1 100644
--- a/libavcodec/dirac_dwt.h
+++ b/libavcodec/dirac_dwt.h
@@ -82,7 +82,7 @@ int ff_spatial_idwt_init2(DWTContext *d, IDWTELEM *buffer, int width, int height
 
 void ff_spatial_idwt_slice2(DWTContext *d, int y);
 
-// shared stuff for simd optimiztions
+// shared stuff for simd optimizations
 #define COMPOSE_53iL0(b0, b1, b2)\
     (b1 - ((b0 + b2 + 2) >> 2))
 
diff --git a/libavcodec/dnxhddata.h b/libavcodec/dnxhddata.h
index b8bcb21d8ea34ee4e433f96df9be7ac9ac9cd764..8166ee848f4e39676da54facbecf08214971c75f 100644
--- a/libavcodec/dnxhddata.h
+++ b/libavcodec/dnxhddata.h
@@ -42,7 +42,7 @@ typedef struct CIDEntry {
     const uint8_t *ac_flags;
     const uint16_t *run_codes;
     const uint8_t *run_bits, *run;
-    int bit_rates[5]; ///< Helpher to choose variants, rounded to nearest 5Mb/s
+    int bit_rates[5]; ///< Helper to choose variants, rounded to nearest 5Mb/s
     AVRational frame_rates[5];
 } CIDEntry;
 
diff --git a/libavcodec/error_resilience.h b/libavcodec/error_resilience.h
index 7352dbb1c92f2e153c737b69eaa6209905f9ff4a..9d227e87a1561896920bf2982af7abfafad52516 100644
--- a/libavcodec/error_resilience.h
+++ b/libavcodec/error_resilience.h
@@ -42,7 +42,7 @@ typedef struct ERPicture {
     AVFrame *f;
     ThreadFrame *tf;
 
-    // it's the caller responsability to allocate these buffers
+    // it's the caller's responsibility to allocate these buffers
     int16_t (*motion_val[2])[2];
     int8_t *ref_index[2];
 
diff --git a/libavcodec/fft_table.h b/libavcodec/fft_table.h
index 687e5b94fd5d5cdcbc10f45ed7aff12dc4bd0a42..7f3142d7a9f7d7762c1671931519c42d6fa97e7f 100644
--- a/libavcodec/fft_table.h
+++ b/libavcodec/fft_table.h
@@ -56,7 +56,7 @@
 
 #include "libavcodec/fft.h"
 
-#define MAX_LOG2_NFFT 16 //!< Specifies maxiumum allowed fft size
+#define MAX_LOG2_NFFT 16 //!< Specifies maximum allowed fft size
 #define MAX_FFT_SIZE (1 << MAX_LOG2_NFFT)
 
 extern int32_t w_tab_sr[];
diff --git a/libavcodec/get_bits.h b/libavcodec/get_bits.h
index 7824e5ab0fda1a17326ebec463fff5929a7d3a11..82421cba32d30aba6c880d2442a8552c08de4749 100644
--- a/libavcodec/get_bits.h
+++ b/libavcodec/get_bits.h
@@ -219,7 +219,7 @@ static inline void skip_bits_long(GetBitContext *s, int n)
 }
 
 /**
- * read mpeg1 dc style vlc (sign bit + mantisse with no MSB).
+ * read mpeg1 dc style vlc (sign bit + mantissa with no MSB).
  * if MSB not set it is negative
  * @param n length in bits
  */
diff --git a/libavcodec/rv30data.h b/libavcodec/rv30data.h
index 9cc48a6a31fd3d0b243e6f638a371b5faa5046a5..5c4cb9710b91d7dc02a3ba24ad5af3c3cf1f3eb8 100644
--- a/libavcodec/rv30data.h
+++ b/libavcodec/rv30data.h
@@ -58,7 +58,7 @@ static const uint8_t rv30_itype_code[9*9*2] = {
  *
  * This is really a three-dimensional matrix with dimensions
  * [-1..9][-1..9][0..9]. The first and second coordinates are
- * detemined by the top and left neighbors (-1 if unavailable).
+ * determined by the top and left neighbors (-1 if unavailable).
  */
 static const uint8_t rv30_itype_from_context[900] = {
     0, 9, 9, 9, 9, 9, 9, 9, 9,
diff --git a/libavdevice/avdevice.h b/libavdevice/avdevice.h
index 92678ebd45ff75797111336fcfa1c83b4ef9c9d9..a39522819ee0fdacd95820255ce2d6c71d9642be 100644
--- a/libavdevice/avdevice.h
+++ b/libavdevice/avdevice.h
@@ -135,7 +135,7 @@ enum AVAppToDevMessageType {
     /**
      * Repaint request message.
      *
-     * Message is sent to the device when window have to be rapainted.
+     * Message is sent to the device when window has to be repainted.
      *
      * data: AVDeviceRect: area required to be repainted.
      *       NULL: whole area is required to be repainted.
@@ -231,7 +231,7 @@ enum AVDevToAppMessageType {
      * Display window buffer message.
      *
      * Device requests to display a window buffer.
-     * Message is sent when new frame is ready to be displyed.
+     * Message is sent when new frame is ready to be displayed.
      * Usually buffers need to be swapped in handler of this message.
      *
      * data: NULL.
@@ -327,7 +327,7 @@ int avdevice_dev_to_app_control_message(struct AVFormatContext *s,
  * Queried capabilities allows to set up converters of video or audio
  * parameters that fit to the device.
  *
- * List of capablities that can be queried:
+ * List of capabilities that can be queried:
  *  - Capabilities valid for both audio and video devices:
  *    - codec:          supported audio/video codecs.
  *                      type: AV_OPT_TYPE_INT (AVCodecID value)
@@ -391,9 +391,9 @@ int avdevice_dev_to_app_control_message(struct AVFormatContext *s,
  */
 
 /**
- * Structure describes device capabilites.
+ * Structure describes device capabilities.
  *
- * It is used by devices in conjuntion with av_device_capabilities AVOption table
+ * It is used by devices in conjunction with av_device_capabilities AVOption table
  * to implement capabilities probing API based on AVOption API. Should not be used directly.
  */
 typedef struct AVDeviceCapabilitiesQuery {
@@ -413,7 +413,7 @@ typedef struct AVDeviceCapabilitiesQuery {
 } AVDeviceCapabilitiesQuery;
 
 /**
- * AVOption table used by devices to implement device capabilites API. Should not be used by a user.
+ * AVOption table used by devices to implement device capabilities API. Should not be used by a user.
  */
 extern const AVOption av_device_capabilities[];
 
@@ -478,7 +478,7 @@ typedef struct AVDeviceInfoList {
 int avdevice_list_devices(struct AVFormatContext *s, AVDeviceInfoList **device_list);
 
 /**
- * Convinient function to free result of avdevice_list_devices().
+ * Convenient function to free result of avdevice_list_devices().
  *
  * @param devices device list to be freed.
  */
diff --git a/libavformat/mux.c b/libavformat/mux.c
index 1c15a91cd05cc6d110a4f31254685b9938fe891d..cdceadd71b406f19f8c5930c5d5fd323c9d6c239 100644
--- a/libavformat/mux.c
+++ b/libavformat/mux.c
@@ -102,7 +102,7 @@ static void frac_add(AVFrac *f, int64_t incr)
     f->num = num;
 }
 
-AVRational ff_choose_timebase(AVFormatContext *s, AVStream *st, int min_precission)
+AVRational ff_choose_timebase(AVFormatContext *s, AVStream *st, int min_precision)
 {
     AVRational q;
     int j;
@@ -113,9 +113,9 @@ AVRational ff_choose_timebase(AVFormatContext *s, AVStream *st, int min_precissi
         q = st->codec->time_base;
     }
     for (j=2; j<14; j+= 1+(j>2))
-        while (q.den / q.num < min_precission && q.num % j == 0)
+        while (q.den / q.num < min_precision && q.num % j == 0)
             q.num /= j;
-    while (q.den / q.num < min_precission && q.den < (1<<24))
+    while (q.den / q.num < min_precision && q.den < (1<<24))
         q.den <<= 1;
 
     return q;
diff --git a/libavformat/internal.h b/libavformat/internal.h
index e9e9293f87ff85cd924020e8cfa912edefb6becb..66fb5d64af27903b2f99ddcbfba791d6e9e344db 100644
--- a/libavformat/internal.h
+++ b/libavformat/internal.h
@@ -360,11 +360,11 @@ enum AVCodecID ff_get_pcm_codec_id(int bps, int flt, int be, int sflags);
 /**
  * Chooses a timebase for muxing the specified stream.
  *
- * The choosen timebase allows sample accurate timestamps based
+ * The chosen timebase allows sample accurate timestamps based
  * on the framerate or sample rate for audio streams. It also is
  * at least as precisse as 1/min_precission would be.
  */
-AVRational ff_choose_timebase(AVFormatContext *s, AVStream *st, int min_precission);
+AVRational ff_choose_timebase(AVFormatContext *s, AVStream *st, int min_precision);
 
 /**
  * Generate standard extradata for AVC-Intra based on width/height and field
@@ -360,11 +360,11 @@ enum AVCodecID ff_get_pcm_codec_id(int bps, int flt, int be, int sflags);
  * on the framerate or sample rate for audio streams. It also is
- * at least as precisse as 1/min_precission would be.
+ * at least as precise as 1/min_precision would be.
  */